@@ -1,8 +1,6 @@
-from __future__ import unicode_literals
-
 from django.core.management.base import BaseCommand
 
-from ...tasks import update_conversion_rates, create_conversion_dates
+from ...tasks import update_conversion_rates, create_conversion_rates
 
 
 class Command(BaseCommand):
@@ -17,7 +15,7 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         if options['all_currencies']:
-            all_rates = create_conversion_dates()
+            all_rates = create_conversion_rates()
         else:
             all_rates = update_conversion_rates()
         for conversion_rate in all_rates:
